@@ -35,12 +35,6 @@
 
 #include <thunar-tpa/thunar-tpa-bindings.h>
 
-#ifdef LIBXFCE4PANEL_CHECK_VERSION
-#if LIBXFCE4PANEL_CHECK_VERSION (4,9,0)
-#define HAS_PANEL_49
-#endif
-#endif
-
 typedef struct _ThunarTpaClass ThunarTpaClass;
 typedef struct _ThunarTpa      ThunarTpa;
 
@@ -59,12 +53,8 @@ GType           thunar_tpa_get_type            (void);
 void            thunar_tpa_register_type       (XfcePanelTypeModule *type_module);
 static void     thunar_tpa_finalize            (GObject             *object);
 static void     thunar_tpa_construct           (XfcePanelPlugin     *panel_plugin);
-
-#ifdef HAS_PANEL_49
 static gboolean thunar_tpa_size_changed        (XfcePanelPlugin     *panel_plugin,
                                                 gint                 size);
-#endif
-
 static void     thunar_tpa_error               (ThunarTpa           *plugin,
                                                 GError              *error);
 static void     thunar_tpa_state               (ThunarTpa           *plugin,
@@ -157,10 +147,7 @@ thunar_tpa_class_init (ThunarTpaClass *klass)
 
   plugin_class = XFCE_PANEL_PLUGIN_CLASS (klass);
   plugin_class->construct = thunar_tpa_construct;
-
-#ifdef HAS_PANEL_49
   plugin_class->size_changed = thunar_tpa_size_changed;
-#endif
 }
 
 
@@ -183,7 +170,7 @@ thunar_tpa_init (ThunarTpa *plugin)
   gtk_widget_show (plugin->button);
 
   /* setup the image for the trash plugin */
-  plugin->image = xfce_panel_image_new_from_source ("user-trash");
+  plugin->image = gtk_image_new_from_icon_name ("user-trash", GTK_ICON_SIZE_BUTTON);
   gtk_container_add (GTK_CONTAINER (plugin->button), plugin->image);
   gtk_widget_show (plugin->image);
 
@@ -246,10 +233,8 @@ thunar_tpa_construct (XfcePanelPlugin *panel_plugin)
 {
   ThunarTpa *plugin = THUNAR_TPA (panel_plugin);
 
-#ifdef HAS_PANEL_49
   /* make the plugin fit a single row */
   xfce_panel_plugin_set_small (panel_plugin, TRUE);
-#endif
 
   /* add the "Empty Trash" menu item */
   xfce_panel_plugin_menu_insert_item (panel_plugin, GTK_MENU_ITEM (plugin->mi));
@@ -260,20 +245,26 @@ thunar_tpa_construct (XfcePanelPlugin *panel_plugin)
 
 
 
-#ifdef HAS_PANEL_49
 static gboolean
 thunar_tpa_size_changed (XfcePanelPlugin *panel_plugin,
                          gint             size)
 {
-  g_return_val_if_fail (panel_plugin != NULL, FALSE);
+  ThunarTpa *plugin = THUNAR_TPA (panel_plugin);
+  gint       image_size;
 
   /* make the plugin fit a single row */
   size /= xfce_panel_plugin_get_nrows (panel_plugin);
   gtk_widget_set_size_request (GTK_WIDGET (panel_plugin), size, size);
 
+#if LIBXFCE4PANEL_CHECK_VERSION (4,13,0)
+  image_size = xfce_panel_plugin_get_icon_size (panel_plugin);
+#else
+  image_size = size - 2; // fall-back for older panel versions
+#endif
+  gtk_image_set_pixel_size (GTK_IMAGE (plugin->image), image_size);
+
   return TRUE;
 }
-#endif
 
 
 
@@ -295,7 +286,7 @@ thunar_tpa_error (ThunarTpa *plugin,
   g_free (tooltip);
 
   /* setup an error plugin */
-  xfce_panel_image_set_from_source (XFCE_PANEL_IMAGE (plugin->image), "stock_dialog-error");
+  gtk_image_set_from_icon_name (GTK_IMAGE (plugin->image), "stock_dialog-error", GTK_ICON_SIZE_BUTTON);
 }
 
 
@@ -308,7 +299,7 @@ thunar_tpa_state (ThunarTpa *plugin,
   gtk_widget_set_tooltip_text (plugin->button, full ? _("Trash contains files") : _("Trash is empty"));
 
   /* setup the appropriate plugin */
-  xfce_panel_image_set_from_source (XFCE_PANEL_IMAGE (plugin->image), full ? "user-trash-full" : "user-trash");
+  gtk_image_set_from_icon_name (GTK_IMAGE (plugin->image), full ? "user-trash-full" : "user-trash", GTK_ICON_SIZE_BUTTON);
 
   /* sensitivity of the menu item */
   gtk_widget_set_sensitive (plugin->mi, full);
