@@ -1,4 +1,4 @@
-/* $Id$ */
+/* vi:set et ai sw=2 sts=2 ts=2: */
 /*-
  * Copyright (c) 2005-2006 Benedikt Meurer <benny@xfce.org>
  * Copyright (c) 2009-2010 Jannis Pohlmann <jannis@xfce.org>
@@ -329,7 +329,7 @@ thunar_create_dialog_set_filename (ThunarCreateDialog *dialog,
   gtk_entry_set_text (GTK_ENTRY (dialog->entry), filename);
 
   /* check if filename contains a dot */
-  dot = g_utf8_strrchr (filename, -1, '.');
+  dot = thunar_util_str_get_extension (filename);
   if (G_LIKELY (dot != NULL))
     {
       /* grab focus to the entry first, else
