@@ -357,6 +357,7 @@ thunar_dbus_service_connect_trash_bin (ThunarDBusService *dbus_service,
           g_signal_connect_swapped (G_OBJECT (dbus_service->trash_bin), "changed",
                                     G_CALLBACK (thunar_dbus_service_trash_bin_changed),
                                     dbus_service);
+          thunar_file_reload_idle (dbus_service->trash_bin);
         }
       g_object_unref (trash_bin_path);
     }
@@ -625,7 +626,7 @@ thunar_dbus_service_execute (ThunarDBusService *dbus_service,
 
       /* try to launch the file on the given screen */
       working_dir = g_file_new_for_commandline_arg (working_directory);
-      result = thunar_file_execute (file, working_dir, screen, file_list, error);
+      result = thunar_file_execute (file, working_dir, screen, file_list, startup_id, error);
       g_object_unref (working_dir);
 
       /* cleanup */
@@ -1288,7 +1289,7 @@ thunar_dbus_service_unlink_files (ThunarDBusService  *dbus_service,
         }
 
       /* check if we succeeded */
-      if (err == NULL)
+      if (err == NULL && file_list != NULL)
         {
           /* tell the application to move the specified files to the trash */
           application = thunar_application_get ();
