@@ -1,4 +1,4 @@
-/* $Id$ */
+/* vi:set et ai sw=2 sts=2 ts=2: */
 /*-
  * Copyright (c) 2005-2007 Benedikt Meurer <benny@xfce.org>
  * Copyright (c) 2009 Jannis Pohlmann <jannis@xfce.org>
@@ -75,6 +75,7 @@ enum
   PROP_MISC_VOLUME_MANAGEMENT,
   PROP_MISC_CASE_SENSITIVE,
   PROP_MISC_DATE_STYLE,
+  PROP_EXEC_SHELL_SCRIPTS_BY_DEFAULT,
   PROP_MISC_FOLDERS_FIRST,
   PROP_MISC_FULL_PATH_IN_TITLE,
   PROP_MISC_HORIZONTAL_WHEEL_NAVIGATES,
@@ -89,6 +90,7 @@ enum
   PROP_MISC_TAB_CLOSE_MIDDLE_CLICK,
   PROP_MISC_TEXT_BESIDE_ICONS,
   PROP_MISC_THUMBNAIL_MODE,
+  PROP_MISC_FILE_SIZE_BINARY,
   PROP_SHORTCUTS_ICON_EMBLEMS,
   PROP_SHORTCUTS_ICON_SIZE,
   PROP_TREE_ICON_EMBLEMS,
@@ -490,6 +492,22 @@ thunar_preferences_class_init (ThunarPreferencesClass *klass)
                          THUNAR_DATE_STYLE_SIMPLE,
                          EXO_PARAM_READWRITE);
 
+  /**
+   * ThunarPreferences:misc-execute-shell-scripts-by-default:
+   *
+   * Shell scripts are often unsafe to execute, require additional
+   * parameters and most users will only want to edit them in their
+   * favorite editor, so the default is to open them in the associated
+   * application. Setting this to TRUE allows executing them, like
+   * binaries, by default. See bug #7596.
+   **/
+  preferences_props[PROP_EXEC_SHELL_SCRIPTS_BY_DEFAULT] =
+      g_param_spec_boolean ("misc-exec-shell-scripts-by-default",
+                            "MiscExecShellScriptsByDefault",
+                            NULL,
+                            FALSE,
+                            EXO_PARAM_READWRITE);
+
   /**
    * ThunarPreferences:misc-folders-first:
    *
@@ -675,6 +693,18 @@ thunar_preferences_class_init (ThunarPreferencesClass *klass)
                          THUNAR_THUMBNAIL_MODE_ONLY_LOCAL,
                          EXO_PARAM_READWRITE);
 
+  /**
+   * ThunarPreferences:misc-file-size-binary:
+   *
+   * Show file size in binary format instead of decimal.
+   **/
+  preferences_props[PROP_MISC_FILE_SIZE_BINARY] =
+      g_param_spec_boolean ("misc-file-size-binary",
+                            "MiscFileSizeBinary",
+                            NULL,
+                            FALSE,
+                            EXO_PARAM_READWRITE);
+
   /**
    * ThunarPreferences:shortcuts-icon-emblems:
    *
