@@ -122,6 +122,8 @@ static void           thunar_shortcuts_view_context_menu                 (Thunar
                                                                           GtkTreeIter              *iter);
 static void           thunar_shortcuts_view_remove_activated             (GtkWidget                *item,
                                                                           GtkTreeModel             *model);
+static void           thunar_shortcuts_view_editing_canceled             (GtkCellRenderer          *renderer,
+                                                                          ThunarShortcutsView      *view);
 static void           thunar_shortcuts_view_rename_activated             (GtkWidget                *item,
                                                                           ThunarShortcutsView      *view);
 static void           thunar_shortcuts_view_renamed                      (GtkCellRenderer          *renderer,
@@ -430,7 +432,7 @@ thunar_shortcuts_view_button_press_event (GtkWidget      *widget,
   if (gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (widget), event->x, event->y, &path, NULL, NULL, NULL))
     {
       /* check if we should popup the context menu */
-      if (G_UNLIKELY (event->button == 3 && event->type == GDK_BUTTON_PRESS))
+      if (G_UNLIKELY (event->button == 3))
         {
           /* determine the iterator for the path */
           if (gtk_tree_model_get_iter (model, &iter, path))
@@ -442,14 +444,12 @@ thunar_shortcuts_view_button_press_event (GtkWidget      *widget,
               result = TRUE;
             }
         }
-      else if ((event->button == 1 || event->button == 2)
-               && event->type == GDK_BUTTON_PRESS
-               && (event->state & gtk_accelerator_get_default_mod_mask ()) == 0)
+      else if (event->button == 1 || event->button == 2)
         {
           /* check if we clicked the eject button area */
           column_width = gtk_tree_view_column_get_width (gtk_tree_view_get_column (GTK_TREE_VIEW (view), 0));
           gtk_icon_size_lookup (GTK_ICON_SIZE_MENU, &icon_width, &icon_height);
-          if (event->x >= column_width - icon_width - 3)
+          if (event->button == 1 && event->x >= column_width - icon_width - 3)
             {
               /* check if that shortcut actually has an eject button */
               model = gtk_tree_view_get_model (GTK_TREE_VIEW (view));
@@ -460,6 +460,8 @@ thunar_shortcuts_view_button_press_event (GtkWidget      *widget,
                     view->pressed_eject_button = 1;
                 }
             }
+          else
+            gtk_tree_view_set_cursor (GTK_TREE_VIEW (widget), path, gtk_tree_view_get_column (GTK_TREE_VIEW (view), 0), FALSE);
 
           /* remember the button as pressed and handle it in the release handler */
           view->pressed_button = event->button;
@@ -503,6 +505,11 @@ thunar_shortcuts_view_button_release_event (GtkWidget      *widget,
         {
           /* button 2 opens in a new window or tab */
           g_object_get (view->preferences, "misc-middle-click-in-tab", &in_tab, NULL);
+
+          /* holding ctrl inverts the action */
+          if ((event->state & GDK_CONTROL_MASK) != 0)
+            in_tab = !in_tab;
+
           thunar_shortcuts_view_open (view, in_tab ? OPEN_IN_TAB : OPEN_IN_WINDOW);
         }
     }
@@ -976,7 +983,8 @@ thunar_shortcuts_view_context_menu_visibility (ThunarShortcutsView *view,
 
   /* process all items below the header */
   child_model = gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER (model));
-  gtk_tree_model_get_iter_first (GTK_TREE_MODEL (child_model), &iter);
+  if (!gtk_tree_model_get_iter_first (GTK_TREE_MODEL (child_model), &iter))
+      return;
   path = gtk_tree_model_get_path (child_model, &iter);
   do
     {
@@ -1313,6 +1321,19 @@ thunar_shortcuts_view_remove_activated (GtkWidget    *item,
 
 
 
+static void
+thunar_shortcuts_view_editing_canceled (GtkCellRenderer     *renderer,
+                                        ThunarShortcutsView *view)
+{
+  g_object_set (G_OBJECT (renderer), "editable", FALSE, NULL);
+
+  g_signal_handlers_disconnect_by_func (G_OBJECT (renderer),
+                                       G_CALLBACK (thunar_shortcuts_view_editing_canceled),
+                                       view);
+}
+
+
+
 static void
 thunar_shortcuts_view_rename_activated (GtkWidget           *item,
                                         ThunarShortcutsView *view)
@@ -1335,6 +1356,10 @@ thunar_shortcuts_view_rename_activated (GtkWidget           *item,
       /* make sure the text renderer is editable */
       g_object_set (G_OBJECT (renderer), "editable", TRUE, NULL);
 
+      /* set up signals for the cell renderer */
+      g_signal_connect (G_OBJECT (renderer), "editing-canceled",
+                        G_CALLBACK (thunar_shortcuts_view_editing_canceled), view);
+
       /* tell the tree view to start editing the given row */
       gtk_tree_view_set_cursor_on_cell (GTK_TREE_VIEW (view), path, column, renderer, TRUE);
 
