@@ -607,11 +607,12 @@ thunar_thumbnailer_queue_async_reply (DBusGProxy *proxy,
                                       GError     *error,
                                       gpointer    user_data)
 {
+  _thunar_return_if_fail (DBUS_IS_G_PROXY (proxy));
+  _thunar_return_if_fail (user_data != NULL);
+
   ThunarThumbnailerJob *job = user_data;
   ThunarThumbnailer    *thumbnailer = THUNAR_THUMBNAILER (job->thumbnailer);
 
-  _thunar_return_if_fail (DBUS_IS_G_PROXY (proxy));
-  _thunar_return_if_fail (job != NULL);
   _thunar_return_if_fail (THUNAR_IS_THUMBNAILER (thumbnailer));
 
   _thumbnailer_lock (thumbnailer);
@@ -931,7 +932,7 @@ thunar_thumbnailer_queue_files (ThunarThumbnailer *thumbnailer,
           thumbnail_path = thunar_file_get_thumbnail_path (lp->data);
 
           /* test if a thumbnail can be found */
-          if (g_file_test (thumbnail_path, G_FILE_TEST_EXISTS))
+          if (thumbnail_path != NULL && g_file_test (thumbnail_path, G_FILE_TEST_EXISTS))
             thunar_file_set_thumb_state (lp->data, THUNAR_FILE_THUMB_STATE_READY);
           else
             thunar_file_set_thumb_state (lp->data, THUNAR_FILE_THUMB_STATE_NONE);
